summaryrefslogtreecommitdiff
path: root/webtest
diff options
context:
space:
mode:
authorGael Pasgrimaud <gael@gawel.org>2015-05-04 22:37:21 +0200
committerGael Pasgrimaud <gael@gawel.org>2015-05-04 22:37:26 +0200
commit1035510088f3a30bcd820c9f4404b93e356827c6 (patch)
tree30d1d2ad0fcb511014207deaa9ad052f3b2928a4 /webtest
parent3ec0c83d096311481979d8440daa4787b87d21bc (diff)
downloadwebtest-1035510088f3a30bcd820c9f4404b93e356827c6.tar.gz
fixed #135
Diffstat (limited to 'webtest')
-rw-r--r--webtest/app.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/webtest/app.py b/webtest/app.py
index fad78ea..d16380f 100644
--- a/webtest/app.py
+++ b/webtest/app.py
@@ -99,7 +99,8 @@ class TestApp(object):
.. versionadded:: 2.0
It can also be an actual full URL to an http server and webtest
- will proxy requests with `wsgiproxy`.
+ will proxy requests with `WSGIProxy2
+ <https://pypi.python.org/pypi/WSGIProxy2/0.4.2>`_.
:type app:
WSGI application
:param extra_environ: